﻿// Demo.FileApi
//
// Copyright © 2018 Eurostep
//
// All rights reserved.
//
// MIT License
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to
// use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
// the Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
// FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
// COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
// CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using Newtonsoft.Json.Linq;

namespace Demo.FileApi
{
    public static partial class Program
    {
        public static void TestAuthenticate()
        {
            string baseAddress = @"https://my.machine1.net";
            string userName = "MyEmail";
            string password = "MyPassword";
            string clientName = "ResourceOwnerClientId";
            string clientSecret = "CLIENTSECRET";
            JObject token = Authenticate(baseAddress, userName, password, clientName, clientSecret);
        }

        public static void TestUploadFileStream()
        {
            string baseAddress = @"https://my.machine1.net";
            string userName = "MyEmail";
            string password = "MyPassword";
            string clientName = "ResourceOwnerClientId";
            string clientSecret = "CLIENTSECRET";
            string spaceId = "mytestspace";
            string remoteFilePath = @"MyFolder/TestFile.txt";
            string localFilePath = @"..\..\..\..\files\TestFile.txt";
            JObject token = Authenticate(baseAddress, userName, password, clientName, clientSecret);
            string accessToken = (string)token["access_token"];
            UploadUserStoreFile(accessToken, baseAddress, remoteFilePath, localFilePath, spaceId);
        }

        public static void TestUploadFileChunked()
        {
            string baseAddress = @"https://my.machine1.net";
            string userName = "MyEmail";
            string password = "MyPassword";
            string clientName = "ResourceOwnerClientId";
            string clientSecret = "CLIENTSECRET";
            string spaceId = "mytestspace";
            string remoteFilePath = @"MyFolder/BigFile.pdf";
            string localFilePath = @"..\..\..\..\files\BigFile.pdf";
            JObject token = Authenticate(baseAddress, userName, password, clientName, clientSecret);
            string accessToken = (string)token["access_token"];
            UploadUserStoreFileChunked(accessToken, baseAddress, remoteFilePath, localFilePath, spaceId);
        }

        public static void TestDownloadFile()
        {
            string baseAddress = @"https://my.machine1.net";
            string userName = "MyEmail";
            string password = "MyPassword";
            string clientName = "ResourceOwnerClientId";
            string clientSecret = "CLIENTSECRET";
            string spaceId = "mytestspace";
            string remoteFilePath = @"MyFolder/TestFile.txt";
            string localFilePath_user = @"..\..\..\..\files\TestFile_user.txt";
            JObject token = Authenticate(baseAddress, userName, password, clientName, clientSecret);
            string accessToken = (string)token["access_token"];
            DownloadUserStoreFile(accessToken, baseAddress, remoteFilePath, localFilePath_user, spaceId);
        }

        public static void TestDeleteFile()
        {
            string baseAddress = @"https://my.machine1.net";
            string userName = "MyEmail";
            string password = "MyPassword";
            string clientName = "ResourceOwnerClientId";
            string clientSecret = "CLIENTSECRET";
            string spaceId = "mytestspace";
            string remoteFilePath = @"MyFolder/TestFile.txt";
            JObject token = Authenticate(baseAddress, userName, password, clientName, clientSecret);
            string accessToken = (string)token["access_token"];
            DeleteUserStoreFile(accessToken, baseAddress, remoteFilePath, spaceId);
        }

        public static void TestBulkUploadFiles()
        {
            string baseAddress = @"http://localhost:5000";
            string sourceDirectory = @"C:\UploadFolder";
            string adminApiSymmetricKey = "8JcfLlO+usfLslIIUNIYofT8FI17l93je/QK6jE/Yhm+cKd/N2iaV26qElc9qpuLNP/ySy/2lAxeIVKd9ONt+w==";
            bool writeLog = true;
            string spaceId = "mytestspace";
            string participantId = "OEM";
            string targetDirectory = "/";
            bool replaceFiles = true;
            bool deleteFilesAfterUpload = false;
            BulkUploadFiles(baseAddress, sourceDirectory, adminApiSymmetricKey, writeLog, spaceId, participantId, targetDirectory, replaceFiles, deleteFilesAfterUpload);
        }
    }
}